pub fn apply_op_for_language(
language: LowerLanguage,
file: &mut File,
op: PatchOp,
) -> Result<(), PatchError>Expand description
Applies a single patch operation to a file using the selected lower language.
pub fn apply_op_for_language(
language: LowerLanguage,
file: &mut File,
op: PatchOp,
) -> Result<(), PatchError>Applies a single patch operation to a file using the selected lower language.