pub fn apply_patch_text_for_language(
language: LowerLanguage,
file: &mut File,
source: &str,
) -> Result<(), PatchTextError>Expand description
Parses, resolves, and applies textual patch ops in order using the selected lower language.
pub fn apply_patch_text_for_language(
language: LowerLanguage,
file: &mut File,
source: &str,
) -> Result<(), PatchTextError>Parses, resolves, and applies textual patch ops in order using the selected lower language.