pub fn parse_patch_ops(
source: &str,
) -> Result<Vec<SurfacePatchOp>, PatchTextError>Expand description
Parses canonical textual patch syntax into unresolved surface ops.
pub fn parse_patch_ops(
source: &str,
) -> Result<Vec<SurfacePatchOp>, PatchTextError>Parses canonical textual patch syntax into unresolved surface ops.