pub struct SurfaceFragment {
pub source: String,
pub span: Span,
}Expand description
Fragment source carried verbatim until schema resolution picks a parser.
Fields
source: Stringspan: SpanTrait Implementations
Sourceimpl Clone for SurfaceFragment
impl Clone for SurfaceFragment
Sourcefn clone(&self) -> SurfaceFragment
fn clone(&self) -> SurfaceFragment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SurfaceFragment
impl Debug for SurfaceFragment
Sourceimpl PartialEq for SurfaceFragment
impl PartialEq for SurfaceFragment
Sourcefn eq(&self, other: &SurfaceFragment) -> bool
fn eq(&self, other: &SurfaceFragment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SurfaceFragment
impl StructuralPartialEq for SurfaceFragment